@@ -14,13 +14,9 @@ from rasa.shared.core.domain import Domain, State
 from rasa.shared.core.events import ActionExecuted, Event
 from rasa.shared.core.generator import TrackerWithCachedStates
 
-from rasa.nlu.model import Trainer
-from rasa.nlu.components import Component
 from rasa.nlu.tokenizers.tokenizer import Tokenizer
-from rasa.nlu.config import RasaNLUModelConfig
 from rasa.shared.nlu.constants import TEXT
 from rasa.shared.nlu.training_data.message import Message
-import rasa.shared.utils.io
 
 logger = logging.getLogger(__name__)
 
@@ -145,7 +141,6 @@ def find_story_conflicts(
     trackers: List[TrackerWithCachedStates],
     domain: Domain,
     max_history: Optional[int] = None,
-    nlu_config: Optional[RasaNLUModelConfig] = None,
 ) -> List[StoryConflict]:
     """Generates `StoryConflict` objects, describing conflicts in the given trackers.
 
@@ -153,7 +148,6 @@ def find_story_conflicts(
         trackers: Trackers in which to search for conflicts.
         domain: The domain.
         max_history: The maximum history length to be taken into account.
-        nlu_config: NLU config.
 
     Returns:
         StoryConflict objects.
@@ -165,58 +159,28 @@ def find_story_conflicts(
     else:
         logger.info("Considering all preceding turns for conflict analysis.")
 
-    tokenizer = _get_tokenizer_from_nlu_config(nlu_config)
-
     # We do this in two steps, to reduce memory consumption:
 
     # Create a 'state -> list of actions' dict, where the state is
     # represented by its hash
     conflicting_state_action_mapping = _find_conflicting_states(
-        trackers, domain, max_history, tokenizer
+        trackers, domain, max_history
     )
 
     # Iterate once more over all states and note the (unhashed) state,
     # for which a conflict occurs
     conflicts = _build_conflicts_from_states(
-        trackers, domain, max_history, conflicting_state_action_mapping, tokenizer,
+        trackers, domain, max_history, conflicting_state_action_mapping
     )
 
     return conflicts
 
 
-def _get_tokenizer_from_nlu_config(
-    nlu_config: Optional[RasaNLUModelConfig] = None,
-) -> Optional[Tokenizer]:
-    """Extracts the first Tokenizer in the NLU pipeline.
-
-    Args:
-        nlu_config: NLU Config.
-
-    Returns:
-        The first Tokenizer in the NLU pipeline, if any.
-    """
-    if not nlu_config:
-        return None
-
-    pipeline: List[Component] = Trainer(nlu_config, skip_validation=True).pipeline
-    tokenizer: Optional[Tokenizer] = None
-    for component in pipeline:
-        if isinstance(component, Tokenizer):
-            if tokenizer:
-                rasa.shared.utils.io.raise_warning(
-                    "The pipeline contains more than one tokenizer. "
-                    "Only the first tokenizer will be used for story validation.",
-                )
-            tokenizer = component
-
-    return tokenizer
-
-
 def _find_conflicting_states(
     trackers: List[TrackerWithCachedStates],
     domain: Domain,
     max_history: Optional[int],
-    tokenizer: Optional[Tokenizer],
+    tokenizer: Optional[Tokenizer] = None,
 ) -> Dict[int, Optional[List[Text]]]:
     """Identifies all states from which different actions follow.
 
@@ -275,7 +239,7 @@ def _build_conflicts_from_states(
     domain: Domain,
     max_history: Optional[int],
     conflicting_state_action_mapping: Dict[int, Optional[List[Text]]],
-    tokenizer: Optional[Tokenizer],
+    tokenizer: Optional[Tokenizer] = None,
 ) -> List["StoryConflict"]:
     """Builds a list of `StoryConflict` objects for each given conflict.
 
@@ -302,7 +266,7 @@ def _build_conflicts_from_states(
                 conflicts[hashed_state] = StoryConflict(element.sliced_states)
 
             conflicts[hashed_state].add_conflicting_action(
-                action=str(element.event), story_name=element.tracker.sender_id,
+                action=str(element.event), story_name=element.tracker.sender_id
             )
 
     # Return list of conflicts that arise from unpredictable actions
