@@ -20,10 +20,7 @@ from rasa.nlu.constants import (
     NUMBER_OF_SUB_TOKENS,
     TOKENS_NAMES,
 )
-from rasa.shared.nlu.constants import (
-    TEXT,
-    ACTION_TEXT,
-)
+from rasa.shared.nlu.constants import TEXT, ACTION_TEXT
 from rasa.utils import train_utils
 
 logger = logging.getLogger(__name__)
@@ -57,7 +54,7 @@ class LanguageModelFeaturizer(DenseFeaturizer, GraphComponent):
         return [Tokenizer]
 
     def __init__(
-        self, config: Dict[Text, Any], execution_context: ExecutionContext,
+        self, config: Dict[Text, Any], execution_context: ExecutionContext
     ) -> None:
         """Initializes the featurizer with the model in the config."""
         super(LanguageModelFeaturizer, self).__init__(
@@ -701,7 +698,7 @@ class LanguageModelFeaturizer(DenseFeaturizer, GraphComponent):
 
         return batch_docs
 
-    def process_training_data(self, training_data: TrainingData,) -> TrainingData:
+    def process_training_data(self, training_data: TrainingData) -> TrainingData:
         """Computes tokens and dense features for each message in training data.
 
         Args:
