@@ -1,7 +1,7 @@
 DOCS_BASE_URL = "https://rasa.com/docs/rasa"
 LEGACY_DOCS_BASE_URL = "https://legacy-docs-v1.rasa.com"
 DOCS_URL_TRAINING_DATA = DOCS_BASE_URL + "/training-data-format"
-DOCS_URL_TRAINING_DATA_NLU = DOCS_BASE_URL + "/nlu-training-data"
+DOCS_URL_TRAINING_DATA_NLU = DOCS_URL_TRAINING_DATA + "#nlu-training-data"
 DOCS_URL_DOMAINS = DOCS_BASE_URL + "/domain"
 DOCS_URL_SLOTS = DOCS_URL_DOMAINS + "#slots"
 DOCS_URL_INTENTS = DOCS_URL_DOMAINS + "#intents"
@@ -13,6 +13,7 @@ DOCS_URL_FORMS = DOCS_BASE_URL + "/forms"
 DOCS_URL_PIPELINE = DOCS_BASE_URL + "/tuning-your-model"
 DOCS_URL_POLICIES = DOCS_BASE_URL + "/policies"
 DOCS_URL_TEST_STORIES = DOCS_BASE_URL + "/testing-your-assistant"
+DOCS_URL_MARKERS = DOCS_BASE_URL + "/markers"
 DOCS_URL_ACTIONS = DOCS_BASE_URL + "/actions"
 DOCS_URL_DEFAULT_ACTIONS = DOCS_BASE_URL + "/default-actions"
 DOCS_URL_CONNECTORS = DOCS_BASE_URL + "/connectors/"
@@ -21,13 +22,11 @@ DOCS_URL_EVENT_BROKERS = DOCS_BASE_URL + "/event-brokers"
 DOCS_URL_PIKA_EVENT_BROKER = DOCS_URL_EVENT_BROKERS + "#pika-event-broker"
 DOCS_URL_TRACKER_STORES = DOCS_BASE_URL + "/tracker-stores"
 DOCS_URL_COMPONENTS = DOCS_BASE_URL + "/components"
+DOCS_URL_GRAPH_COMPONENTS = DOCS_BASE_URL + "/custom-graph-components"
 DOCS_URL_MIGRATION_GUIDE = DOCS_BASE_URL + "/migration-guide"
 DOCS_URL_MIGRATION_GUIDE_MD_DEPRECATION = (
     f"{DOCS_URL_MIGRATION_GUIDE}#rasa-21-to-rasa-22"
 )
-DOCS_URL_MIGRATION_GUIDE_WEIGHT_SPARSITY = (
-    f"{DOCS_URL_MIGRATION_GUIDE}#rasa-24-to-rasa-25"
-)
 DOCS_URL_TELEMETRY = DOCS_BASE_URL + "/telemetry/telemetry"
 DOCS_BASE_URL_RASA_X = "https://rasa.com/docs/rasa-x"
 DOCS_BASE_URL_ACTION_SERVER = "https://rasa.com/docs/action-server"
@@ -35,13 +34,13 @@ DOCS_BASE_URL_ACTION_SERVER = "https://rasa.com/docs/action-server"
 INTENT_MESSAGE_PREFIX = "/"
 
 PACKAGE_NAME = "rasa"
-NEXT_MAJOR_VERSION_FOR_DEPRECATIONS = "3.0.0"
+NEXT_MAJOR_VERSION_FOR_DEPRECATIONS = "4.0.0"
 
 MODEL_CONFIG_SCHEMA_FILE = "shared/utils/schemas/model_config.yml"
 CONFIG_SCHEMA_FILE = "shared/utils/schemas/config.yml"
 RESPONSES_SCHEMA_FILE = "shared/nlu/training_data/schemas/responses.yml"
 SCHEMA_EXTENSIONS_FILE = "shared/utils/pykwalify_extensions.py"
-LATEST_TRAINING_DATA_FORMAT_VERSION = "2.0"
+LATEST_TRAINING_DATA_FORMAT_VERSION = "3.0"
 
 DOMAIN_SCHEMA_FILE = "shared/utils/schemas/domain.yml"
 
@@ -55,6 +54,7 @@ TEST_STORIES_FILE_PREFIX = "test_"
 
 DEFAULT_LOG_LEVEL = "INFO"
 ENV_LOG_LEVEL = "LOG_LEVEL"
+TCP_PROTOCOL = "TCP"
 
 DEFAULT_SENDER_ID = "default"
 UTTER_PREFIX = "utter_"
@@ -89,10 +89,12 @@ DEFAULT_NLU_RESULTS_PATH = "nlu_comparison_results"
 DEFAULT_CORE_SUBDIRECTORY_NAME = "core"
 DEFAULT_NLU_SUBDIRECTORY_NAME = "nlu"
 DEFAULT_CONVERSATION_TEST_PATH = "tests"
+DEFAULT_MARKERS_PATH = "markers"
+DEFAULT_MARKERS_CONFIG_PATH = "markers/config"
+DEFAULT_MARKERS_OUTPUT_PATH = "markers/output"
+DEFAULT_MARKERS_STATS_PATH = "markers/stats"
 
 DIAGNOSTIC_DATA = "diagnostic_data"
 
 RESPONSE_CONDITION = "condition"
 CHANNEL = "channel"
-DEFAULT_YAML_SEQUENCE_INDENT_ENV_VAR = "DEFAULT_YAML_SEQUENCE_INDENT"
-DEFAULT_YAML_SEQUENCE_INDENT = 2
