@@ -17,7 +17,7 @@ class StoryReader:
     """Helper class to read a story file."""
 
     def __init__(
-        self, domain: Optional[Domain] = None, source_name: Optional[Text] = None,
+        self, domain: Optional[Domain] = None, source_name: Optional[Text] = None
     ) -> None:
         """Constructor for the StoryReader.
 
