@@ -18,31 +18,13 @@ from rasa.shared.nlu.constants import (
 
 import rasa.shared.utils.io
 import typing
+from typing import Text, Dict, Any, Union, List
 from collections import defaultdict
-from typing import List, Text, Dict, Any, Union
 
 if typing.TYPE_CHECKING:
     from rasa.shared.nlu.training_data.training_data import TrainingData
 
 
-class TrainingDataReader(abc.ABC):
-    """Reader for NLU training data."""
-
-    def __init__(self) -> None:
-        """Creates reader instance."""
-        self.filename: Text = ""
-
-    def read(self, filename: Union[Text, Path], **kwargs: Any) -> "TrainingData":
-        """Reads TrainingData from a file."""
-        self.filename = filename
-        return self.reads(rasa.shared.utils.io.read_file(filename), **kwargs)
-
-    @abc.abstractmethod
-    def reads(self, s: Text, **kwargs: Any) -> "TrainingData":
-        """Reads TrainingData from a string."""
-        raise NotImplementedError
-
-
 def _raise_on_same_start_and_different_end_positions(
     aggregated_entities: Dict[int, List[Dict[Text, Any]]],
 ) -> None:
@@ -64,11 +46,29 @@ def _raise_on_same_start_and_different_end_positions(
                 )
 
 
+class TrainingDataReader(abc.ABC):
+    """Reader for NLU training data."""
+
+    def __init__(self) -> None:
+        """Creates reader instance."""
+        self.filename: Text = ""
+
+    def read(self, filename: Union[Text, Path], **kwargs: Any) -> "TrainingData":
+        """Reads TrainingData from a file."""
+        self.filename = filename
+        return self.reads(rasa.shared.utils.io.read_file(filename), **kwargs)
+
+    @abc.abstractmethod
+    def reads(self, s: Text, **kwargs: Any) -> "TrainingData":
+        """Reads TrainingData from a string."""
+        raise NotImplementedError
+
+
 class TrainingDataWriter:
-    """Base class for training data writiers."""
+    """A class for writing training data to a file."""
 
     def dump(self, filename: Text, training_data: "TrainingData") -> None:
-        """Writes a TrainingData object in markdown format to a file."""
+        """Writes a TrainingData object to a file."""
         s = self.dumps(training_data)
         rasa.shared.utils.io.write_text_file(s, filename)
 
@@ -126,7 +126,6 @@ class TrainingDataWriter:
             entities_with_start_and_end = [
                 e for e in entities if "start" in e and "end" in e
             ]
-
             # Multiple entities can share the same position span. To account for that,
             # group all entities by their start positions
             aggregated_entities: Dict[int, List[Dict[Text, Any]]] = defaultdict(list)
@@ -138,7 +137,8 @@ class TrainingDataWriter:
             for start, entities in sorted(aggregated_entities.items()):
                 md += text[pos:start]
                 md += TrainingDataWriter.generate_entity(
-                    text, entities[0] if len(entities) == 1 else entities,
+                    text,
+                    entities[0] if len(entities) == 1 else entities,
                 )
                 pos = entities[0]["end"]
 
@@ -232,7 +232,7 @@ class TrainingDataWriter:
 
 
 class JsonTrainingDataReader(TrainingDataReader):
-    """Training data reader specific for JSON files."""
+    """A class for reading JSON files."""
 
     def reads(self, s: Text, **kwargs: Any) -> "TrainingData":
         """Transforms string into json object and passes it on."""
