@@ -5,7 +5,6 @@ import typing
 from typing import Optional, Text, Callable, Dict, Any
 
 import rasa.shared.utils.io
-from rasa.shared.nlu.training_data.formats import MarkdownReader, NLGMarkdownReader
 from rasa.shared.nlu.training_data.formats.dialogflow import (
     DIALOGFLOW_AGENT,
     DIALOGFLOW_ENTITIES,
@@ -25,10 +24,8 @@ logger = logging.getLogger(__name__)
 WIT = "wit"
 LUIS = "luis"
 RASA = "rasa_nlu"
-MARKDOWN = "md"
 RASA_YAML = "rasa_yml"
 UNK = "unk"
-MARKDOWN_NLG = "nlg.md"
 DIALOGFLOW_RELEVANT = {DIALOGFLOW_ENTITIES, DIALOGFLOW_INTENT}
 
 _json_format_heuristics: Dict[Text, Callable[[Any, Text], bool]] = {
@@ -72,12 +69,10 @@ def _reader_factory(fformat: Text) -> Optional["TrainingDataReader"]:
     """Generates the appropriate reader class based on the file format."""
     from rasa.shared.nlu.training_data.formats import (
         RasaYAMLReader,
-        MarkdownReader,
         WitReader,
         LuisReader,
         RasaReader,
         DialogflowReader,
-        NLGMarkdownReader,
     )
 
     reader = None
@@ -89,10 +84,6 @@ def _reader_factory(fformat: Text) -> Optional["TrainingDataReader"]:
         reader = DialogflowReader()
     elif fformat == RASA:
         reader = RasaReader()
-    elif fformat == MARKDOWN:
-        reader = MarkdownReader()
-    elif fformat == MARKDOWN_NLG:
-        reader = NLGMarkdownReader()
     elif fformat == RASA_YAML:
         reader = RasaYAMLReader()
     return reader
@@ -133,11 +124,7 @@ def guess_format(filename: Text) -> Text:
         content = rasa.shared.utils.io.read_file(filename)
         js = json.loads(content)
     except ValueError:
-        if MarkdownReader.is_markdown_nlu_file(filename):
-            guess = MARKDOWN
-        elif NLGMarkdownReader.is_markdown_nlg_file(filename):
-            guess = MARKDOWN_NLG
-        elif RasaYAMLReader.is_yaml_nlu_file(filename):
+        if RasaYAMLReader.is_yaml_nlu_file(filename):
             guess = RASA_YAML
     else:
         for file_format, format_heuristic in _json_format_heuristics.items():
