@@ -1,4 +1,5 @@
 import asyncio
+import contextlib
 from datetime import datetime
 from functools import wraps
 import hashlib
@@ -13,8 +14,6 @@ import textwrap
 import typing
 from typing import Any, Callable, Dict, List, Optional, Text
 import uuid
-
-import async_generator
 import requests
 from terminaltables import SingleTable
 
@@ -26,6 +25,7 @@ from rasa.constants import (
     CONFIG_TELEMETRY_ENABLED,
     CONFIG_TELEMETRY_ID,
 )
+from rasa.engine.storage.local_model_storage import LocalModelStorage
 from rasa.shared.constants import DOCS_URL_TELEMETRY
 from rasa.shared.exceptions import RasaException
 import rasa.shared.utils.io
@@ -94,6 +94,10 @@ TELEMETRY_RASA_X_LOCAL_STARTED_EVENT = "Rasa X Local Started"
 TELEMETRY_VISUALIZATION_STARTED_EVENT = "Story Visualization Started"
 TELEMETRY_TEST_CORE_EVENT = "Model Core Tested"
 TELEMETRY_TEST_NLU_EVENT = "Model NLU Tested"
+TELEMETRY_MARKERS_EXTRACTION_INITIATED_EVENT = "Markers Extraction Initiated"
+TELEMETRY_MARKERS_EXTRACTED_EVENT = "Markers Extracted"
+TELEMETRY_MARKERS_STATS_COMPUTED_EVENT = "Markers Statistics Computed"
+TELEMETRY_MARKERS_PARSED_COUNT = "Markers Parsed"
 
 # used to calculate the context on the first call and cache it afterwards
 TELEMETRY_CONTEXT = None
@@ -450,10 +454,11 @@ def _is_docker() -> bool:
 
 
 def with_default_context_fields(
-    context: Optional[Dict[Text, Any]] = None,
+    context: Optional[Dict[Text, Any]] = None
 ) -> Dict[Text, Any]:
-    """Return a new context dictionary that contains the default field values merged
-    with the provided ones. The default fields contain only the OS information for now.
+    """Return a new context dictionary with default and provided field values merged.
+
+    The default fields contain only the OS information for now.
 
     Args:
         context: Context information about the event.
@@ -472,7 +477,6 @@ def _default_context_fields() -> Dict[Text, Any]:
     Return:
         A new context containing information about the runtime environment.
     """
-
     global TELEMETRY_CONTEXT
 
     if not TELEMETRY_CONTEXT:
@@ -580,7 +584,7 @@ def filter_errors(
         the event without any sensitive / PII data or `None` if the event constitutes
         an `ImportError` which should be discarded.
     """
-    if "exc_info" in hint:
+    if hint and "exc_info" in hint:
         exc_type, exc_value, tb = hint.get("exc_info")
         if isinstance(exc_value, ImportError):
             return None
@@ -715,10 +719,10 @@ def initialize_error_reporting() -> None:
             scope.set_context("Environment", default_context)
 
 
-@async_generator.asynccontextmanager
-async def track_model_training(
+@contextlib.contextmanager
+def track_model_training(
     training_data: "TrainingDataImporter", model_type: Text, is_finetuning: bool = False
-) -> typing.AsyncGenerator[None, None]:
+) -> typing.Generator[None, None, None]:
     """Track a model training started.
 
     WARNING: since this is a generator, it can't use the ensure telemetry
@@ -734,13 +738,18 @@ async def track_model_training(
     if not initialize_telemetry():
         # telemetry reporting is disabled. we won't do any reporting
         yield  # runs the training
-        return  # closes the async context
+        return
 
-    config = await training_data.get_config()
-    stories = await training_data.get_stories()
-    nlu_data = await training_data.get_nlu_data()
-    domain = await training_data.get_domain()
+    config = training_data.get_config()
+    stories = training_data.get_stories()
+    nlu_data = training_data.get_nlu_data()
+    domain = training_data.get_domain()
     count_conditional_responses = domain.count_conditional_response_variations()
+    (
+        count_total_mappings,
+        count_custom_mappings,
+        count_conditional_mappings,
+    ) = domain.count_slot_mapping_statistics()
 
     training_id = uuid.uuid4().hex
 
@@ -761,6 +770,9 @@ async def track_model_training(
             # 'templates' in the domain
             "num_templates": len(domain.responses),
             "num_conditional_response_variations": count_conditional_responses,
+            "num_slot_mappings": count_total_mappings,
+            "num_custom_slot_mappings": count_custom_mappings,
+            "num_conditional_slot_mappings": count_conditional_mappings,
             "num_slots": len(domain.slots),
             "num_forms": len(domain.forms),
             "num_intents": len(domain.intents),
@@ -874,7 +886,7 @@ def track_server_start(
     number_of_workers: int,
     is_api_enabled: bool,
 ) -> None:
-    """Track when a user starts a rasa server.
+    """Tracks when a user starts a rasa server.
 
     Args:
         input_channels: Used input channels
@@ -888,15 +900,17 @@ def track_server_start(
     def project_fingerprint_from_model(
         _model_directory: Optional[Text],
     ) -> Optional[Text]:
-        """Get project fingerprint from an app's loaded model."""
-        if _model_directory:
-            try:
-                with model.get_model(_model_directory) as unpacked_model:
-                    fingerprint = model.fingerprint_from_path(unpacked_model)
-                    return fingerprint.get(model.FINGERPRINT_PROJECT)
-            except Exception:
-                return None
-        return None
+        """Gets project fingerprint from an app's loaded model."""
+        if not model_directory:
+            return None
+
+        try:
+            model_archive = model.get_local_model(_model_directory)
+            metadata = LocalModelStorage.metadata_from_archive(model_archive)
+
+            return metadata.project_fingerprint
+        except Exception:
+            return None
 
     if not endpoints:
         endpoints = AvailableEndpoints()
@@ -969,11 +983,13 @@ def track_core_model_test(num_story_steps: int, e2e: bool, agent: "Agent") -> No
         e2e: indicator if tests running in end to end mode
         agent: Agent of the model getting tested
     """
-    fingerprint = model.fingerprint_from_path(agent.model_directory or "")
-    project = fingerprint.get(model.FINGERPRINT_PROJECT)
     _track(
         TELEMETRY_TEST_CORE_EVENT,
-        {"project": project, "end_to_end": e2e, "num_story_steps": num_story_steps},
+        {
+            "project": agent.processor.model_metadata.project_fingerprint,
+            "end_to_end": e2e,
+            "num_story_steps": num_story_steps,
+        },
     )
 
 
@@ -994,3 +1010,68 @@ def track_nlu_model_test(test_data: "TrainingData") -> None:
             "num_regexes": len(test_data.regex_features),
         },
     )
+
+
+@ensure_telemetry_enabled
+def track_markers_extraction_initiated(
+    strategy: Text, only_extract: bool, seed: bool, count: Optional[int]
+) -> None:
+    """Track when a user tries to extract success markers.
+
+    Args:
+        strategy: The strategy the user is using for tracker selection
+        only_extract: Indicates if the user is only extracting markers or also
+                      producing stats
+        seed: Indicates if the user used a seed for this attempt
+        count: (Optional) The number of trackers the user is trying to select.
+    """
+    _track(
+        TELEMETRY_MARKERS_EXTRACTION_INITIATED_EVENT,
+        {
+            "strategy": strategy,
+            "only_extract": only_extract,
+            "seed": seed,
+            "count": count,
+        },
+    )
+
+
+@ensure_telemetry_enabled
+def track_markers_extracted(trackers_count: int) -> None:
+    """Track when markers have been extracted by a user.
+
+    Args:
+        trackers_count: The actual number of trackers processed
+    """
+    _track(TELEMETRY_MARKERS_EXTRACTED_EVENT, {"trackers_count": trackers_count})
+
+
+@ensure_telemetry_enabled
+def track_markers_stats_computed(trackers_count: int) -> None:
+    """Track when stats over markers have been computed by a user.
+
+    Args:
+        trackers_count: The actual number of trackers processed
+    """
+    _track(TELEMETRY_MARKERS_STATS_COMPUTED_EVENT, {"trackers_count": trackers_count})
+
+
+@ensure_telemetry_enabled
+def track_markers_parsed_count(
+    marker_count: int, max_depth: int, branching_factor: int
+) -> None:
+    """Track when markers have been successfully parsed from config.
+
+    Args:
+        marker_count: The number of markers found in the config
+        max_depth: The maximum depth of any marker in the config
+        branching_factor: The maximum number of children of any marker in the config.
+    """
+    _track(
+        TELEMETRY_MARKERS_PARSED_COUNT,
+        {
+            "marker_count": marker_count,
+            "max_depth": max_depth,
+            "branching_factor": branching_factor,
+        },
+    )
