@@ -76,7 +76,7 @@ class RasaDataGenerator(tf.keras.utils.Sequence):
         start: Optional[int] = None,
         end: Optional[int] = None,
         tuple_sizes: Optional[Dict[Text, int]] = None,
-    ) -> Tuple[Optional[np.ndarray]]:
+    ) -> Tuple[Optional[np.ndarray], ...]:
         """Slices model data into batch using given start and end value.
 
         Args:
@@ -365,9 +365,9 @@ class RasaBatchDataGenerator(RasaDataGenerator):
         # set current epoch to `-1`, so that `on_epoch_end` will increase it to `0`
         self._current_epoch = -1
         # actual batch size will be set inside `on_epoch_end`
-        self._current_batch_size = None
+        self._current_batch_size = 0
         # create separate data variable that will store modified data for each batch
-        self._data = None
+        self._data = {}
         self.on_epoch_end()
 
     def __len__(self) -> int:
