@@ -10,22 +10,13 @@ from rasa.utils.tensorflow.constants import (
     MARGIN,
     COSINE,
     INNER,
-    LINEAR_NORM,
     CROSS_ENTROPY,
     LABEL,
     LABEL_PAD_ID,
 )
 from rasa.core.constants import DIALOGUE
-from rasa.shared.nlu.constants import (
-    FEATURE_TYPE_SENTENCE,
-    FEATURE_TYPE_SEQUENCE,
-)
-from rasa.shared.nlu.constants import (
-    TEXT,
-    INTENT,
-    ACTION_NAME,
-    ACTION_TEXT,
-)
+from rasa.shared.nlu.constants import FEATURE_TYPE_SENTENCE, FEATURE_TYPE_SEQUENCE
+from rasa.shared.nlu.constants import TEXT, INTENT, ACTION_NAME, ACTION_TEXT
 
 from rasa.utils.tensorflow.exceptions import TFLayerConfigException
 import rasa.utils.tensorflow.layers_utils as layers_utils
@@ -555,10 +546,7 @@ class InputMask(tf.keras.layers.Layer):
 
             return tf.where(tf.tile(lm_mask_bool, (1, 1, x.shape[-1])), x_other, x)
 
-        return (
-            smart_cond(training, x_masked, lambda: tf.identity(x)),
-            lm_mask_bool,
-        )
+        return (smart_cond(training, x_masked, lambda: tf.identity(x)), lm_mask_bool)
 
 
 def _scale_loss(log_likelihood: tf.Tensor) -> tf.Tensor:
@@ -729,7 +717,7 @@ class DotProductLoss(tf.keras.layers.Layer):
                 ensure that similarity values are approximately bounded.
                 Used inside _loss_cross_entropy() only.
             model_confidence: Normalization of confidence values during inference.
-                Possible values are `SOFTMAX` and `LINEAR_NORM`.
+                Currently, the only possible value is `SOFTMAX`.
             similarity_type: Similarity measure to use, either `cosine` or `inner`.
             name: Optional name of the layer.
 
@@ -804,12 +792,6 @@ class DotProductLoss(tf.keras.layers.Layer):
         confidences = similarities
         if self.model_confidence == SOFTMAX:
             confidences = tf.nn.softmax(similarities)
-        elif self.model_confidence == LINEAR_NORM:
-            # Clip negative values to 0 and linearly normalize to bring the predictions
-            # in the range [0,1].
-            clipped_similarities = tf.nn.relu(similarities)
-            normalization = tf.reduce_sum(clipped_similarities, axis=-1)
-            confidences = tf.math.divide_no_nan(clipped_similarities, normalization)
         return similarities, confidences
 
     def call(self, *args: Any, **kwargs: Any) -> Tuple[tf.Tensor, tf.Tensor]:
@@ -896,7 +878,7 @@ class SingleLabelDotProductLoss(DotProductLoss):
                 sigmoid loss term is added to the total loss to ensure that similarity
                 values are approximately bounded.
             model_confidence: Normalization of confidence values during inference.
-                Possible values are `SOFTMAX` and `LINEAR_NORM`.
+                Currently, the only possible value is `SOFTMAX`.
         """
         super().__init__(
             num_candidates,
@@ -1260,7 +1242,7 @@ class MultiLabelDotProductLoss(DotProductLoss):
                 ensure that similarity values are approximately bounded.
                 Used inside _loss_cross_entropy() only.
             model_confidence: Normalization of confidence values during inference.
-                Possible values are `SOFTMAX` and `LINEAR_NORM`.
+                Currently, the only possible value is `SOFTMAX`.
         """
         super().__init__(
             num_candidates,
@@ -1446,7 +1428,7 @@ class MultiLabelDotProductLoss(DotProductLoss):
         )
 
         pos_labels_embed = tf.expand_dims(
-            batch_labels_embed, axis=1, name="expand_pos_labels",
+            batch_labels_embed, axis=1, name="expand_pos_labels"
         )
 
         # Pick random examples from the batch
@@ -1464,7 +1446,7 @@ class MultiLabelDotProductLoss(DotProductLoss):
 
         # Get binary indicators of whether a candidate is positive or not
         pos_neg_indicators = self._get_pos_neg_indicators(
-            all_labels_ids, batch_labels_ids, candidate_ids,
+            all_labels_ids, batch_labels_ids, candidate_ids
         )
 
         return (
