@@ -4,17 +4,7 @@ import numpy as np
 import scipy.sparse
 
 from sklearn.model_selection import train_test_split
-from typing import (
-    Optional,
-    Dict,
-    Text,
-    List,
-    Tuple,
-    Any,
-    Union,
-    NamedTuple,
-    ItemsView,
-)
+from typing import Optional, Dict, Text, List, Tuple, Any, Union, NamedTuple, ItemsView
 from collections import defaultdict, OrderedDict
 
 logger = logging.getLogger(__name__)
@@ -264,7 +254,7 @@ class RasaModelData:
         self.label_sub_key = label_sub_key
         # should be updated when features are added
         self.num_examples = self.number_of_examples()
-        self.sparse_feature_sizes = None
+        self.sparse_feature_sizes = {}
 
     def get(
         self, key: Text, sub_key: Optional[Text] = None
@@ -741,7 +731,7 @@ class RasaModelData:
                 if min(num_data_cycles) > 0:
                     break
 
-        final_data = defaultdict(lambda: defaultdict(list))
+        final_data: Data = defaultdict(lambda: defaultdict(list))
         for key, attribute_data in new_data.items():
             for sub_key, features in attribute_data.items():
                 for f in features:
@@ -789,7 +779,7 @@ class RasaModelData:
         Returns:
             The filtered data
         """
-        new_data = defaultdict(lambda: defaultdict(list))
+        new_data: Data = defaultdict(lambda: defaultdict(list))
 
         if data is None:
             return new_data
