@@ -3,15 +3,7 @@ import numpy as np
 import logging
 import random
 from collections import defaultdict
-from typing import (
-    List,
-    Text,
-    Dict,
-    Tuple,
-    Union,
-    Optional,
-    Any,
-)
+from typing import List, Text, Dict, Tuple, Union, Optional, Any
 
 from rasa.shared.constants import DIAGNOSTIC_DATA
 from rasa.utils.tensorflow.constants import (
@@ -303,8 +295,8 @@ class RasaModel(TmpKerasModel):
             Model outputs corresponding to the inputs fed.
         """
         outputs = {}
-        (data_generator, _,) = rasa.utils.train_utils.create_data_generators(
-            model_data=model_data, batch_sizes=batch_size, epochs=1, shuffle=False,
+        (data_generator, _) = rasa.utils.train_utils.create_data_generators(
+            model_data=model_data, batch_sizes=batch_size, epochs=1, shuffle=False
         )
         data_iterator = iter(data_generator)
         while True:
@@ -365,14 +357,16 @@ class RasaModel(TmpKerasModel):
     def _empty_lists_to_none_in_dict(input_dict: Dict[Text, Any]) -> Dict[Text, Any]:
         """Recursively replaces empty list or np array with None in a dictionary."""
 
-        def _recurse(x: Union[Dict[Text, Any], List[Any], np.ndarray]) -> Optional[Any]:
+        def _recurse(
+            x: Union[Dict[Text, Any], List[Any], np.ndarray]
+        ) -> Optional[Union[Dict[Text, Any], List[np.ndarray]]]:
             if isinstance(x, dict):
                 return {k: _recurse(v) for k, v in x.items()}
             elif (isinstance(x, list) or isinstance(x, np.ndarray)) and np.size(x) == 0:
                 return None
             return x
 
-        return _recurse(input_dict)
+        return {k: _recurse(v) for k, v in input_dict.items()}
 
     def _get_metric_results(self, prefix: Optional[Text] = "") -> Dict[Text, float]:
         return {
@@ -455,7 +449,9 @@ class RasaModel(TmpKerasModel):
         if isinstance(batch[0], Tuple):
             batch = batch[0]
 
-        batch_data = defaultdict(lambda: defaultdict(list))
+        batch_data: Dict[Text, Dict[Text, List[tf.Tensor]]] = defaultdict(
+            lambda: defaultdict(list)
+        )
 
         idx = 0
         for key, values in data_signature.items():
@@ -550,9 +546,7 @@ class TransformerRasaModel(RasaModel):
         data_signature: Dict[Text, Dict[Text, List[FeatureSignature]]],
         label_data: RasaModelData,
     ) -> None:
-        super().__init__(
-            name=name, random_seed=config[RANDOM_SEED],
-        )
+        super().__init__(name=name, random_seed=config[RANDOM_SEED])
 
         self.config = config
         self.data_signature = data_signature
@@ -740,9 +734,7 @@ class TransformerRasaModel(RasaModel):
 
     def _prepare_embed_layers(self, name: Text, prefix: Text = "embed") -> None:
         self._tf_layers[f"{prefix}.{name}"] = layers.Embed(
-            self.config[EMBEDDING_DIMENSION],
-            self.config[REGULARIZATION_CONSTANT],
-            name,
+            self.config[EMBEDDING_DIMENSION], self.config[REGULARIZATION_CONSTANT], name
         )
 
     def _prepare_ffnn_layer(
@@ -761,7 +753,7 @@ class TransformerRasaModel(RasaModel):
         )
 
     def _prepare_dot_product_loss(
-        self, name: Text, scale_loss: bool, prefix: Text = "loss",
+        self, name: Text, scale_loss: bool, prefix: Text = "loss"
     ) -> None:
         self._tf_layers[f"{prefix}.{name}"] = self.dot_product_loss_layer(
             self.config[NUM_NEG],
@@ -836,7 +828,7 @@ class TransformerRasaModel(RasaModel):
         return tf.zeros([batch_dim], dtype=tf.int32)
 
     def _get_sentence_feature_lengths(
-        self, tf_batch_data: Dict[Text, Dict[Text, List[tf.Tensor]]], key: Text,
+        self, tf_batch_data: Dict[Text, Dict[Text, List[tf.Tensor]]], key: Text
     ) -> tf.Tensor:
         """Fetches the sequence lengths of sentence-level features per input example.
 
@@ -859,7 +851,8 @@ class TransformerRasaModel(RasaModel):
         for key, data in attribute_data.items():
             if data:
                 return tf.shape(data[0])[0]
-        return None
+
+        return 0
 
     def _calculate_entity_loss(
         self,
